@@ -1,5 +1,5 @@
 <?php
-//VERSION=0.7
+//VERSION=0.8
 $info = get_token_info();
 
 $user = $info['email'];
@@ -58,14 +58,6 @@ function get_token_info()
 	if (!filter_var($file_data['ip'], FILTER_VALIDATE_IP))
 		die_rm("invalid token IP", $token_file);
 
-	$token_ip = inet_pton($file_data['ip']);
-	$client_ip= inet_pton($_SERVER['REMOTE_ADDR']);
-	if ($token_ip != $client_ip)
-	{
-		error_log("RoundCube: direct_login: IP mismatch '$token_ip' != '$client_ip'");
-		die_rm("IP mismatch", $token_file);
-	}
-
 	//allow only 10 seconds to ues the token.
 	$timeout = 10;
 	if (isset($file_data['timeout']) && is_numeric($file_data['timeout']))
